import { createHead, renderHeadToString } from "@vueuse/head";
import { computed, ref, watchEffect, onBeforeUnmount, getCurrentInstance } from "vue";
import defu from "defu";
import { defineNuxtPlugin } from "#app";
export default defineNuxtPlugin((nuxtApp) => {
  const head = createHead();
  nuxtApp.vueApp.use(head);
  let headReady = false;
  nuxtApp.hooks.hookOnce("app:mounted", () => {
    watchEffect(() => {
      head.updateDOM();
    });
    headReady = true;
  });
  nuxtApp._useHead = (_meta) => {
    const meta = ref(_meta);
    const headObj = computed(() => {
      const overrides = { meta: [] };
      if (meta.value.charset) {
        overrides.meta.push({ key: "charset", charset: meta.value.charset });
      }
      if (meta.value.viewport) {
        overrides.meta.push({ name: "viewport", content: meta.value.viewport });
      }
      return defu(overrides, meta.value);
    });
    head.addHeadObjs(headObj);
    if (process.server) {
      return;
    }
    if (headReady) {
      watchEffect(() => {
        head.updateDOM();
      });
    }
    const vm = getCurrentInstance();
    if (!vm) {
      return;
    }
    onBeforeUnmount(() => {
      head.removeHeadObjs(headObj);
      head.updateDOM();
    });
  };
  if (process.server) {
    nuxtApp.ssrContext.renderMeta = () => {
      const meta = renderHeadToString(head);
      return {
        ...meta,
        bodyScripts: meta.bodyTags
      };
    };
  }
});
